.. grid-strategy documentation master file, created by
   sphinx-quickstart on Sat Feb 23 12:01:54 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===========================
Grid Strategy Documentation
===========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   code

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`